#
# spec file for package python-qtwebengine-qt5
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%define mname qtwebengine-qt5
%{?sle15_python_module_pythons}
Name:           python-%{mname}
Version:        5.15.6
Release:        6.1
Summary:        Python bindings for the Qt5 WebEngine framework
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://www.riverbankcomputing.com/software/pyqtwebengine/intro
Source:         https://files.pythonhosted.org/packages/source/P/PyQtWebEngine/PyQtWebEngine-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyqt-builder >= 1.9}
BuildRequires:  %{python_module qt5-devel >= 5.15.4}
BuildRequires:  %{python_module sip-devel >= 5.3}
BuildRequires:  python-pyqt-rpm-macros
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt5WebEngine)
Requires:       python-qt5 >= %(rpm -q --whatprovides python-qt5 --qf "%%{version}")
Requires:       python-qt5-sip
Provides:       python-PyQtWebEngine = %{version}-%{release}
# http://www.chromium.org/blink is not ported to PowerPC & s390, so Qt5WebEngine itself doesn't build on those archs
ExcludeArch:    ppc ppc64 ppc64le s390 s390x

%python_subpackages

%description
PyQtWebEngine is a set of Python bindings for the Qt5 WebEngine
framework. The framework provides the ability to embed web
content in applications.

%package devel
Summary:        Development files for %{name}
Provides:       %{oldpython}-%{mname}-sip = %{version}-%{release}
Obsoletes:      %{oldpython}-%{mname}-sip < %{version}-%{release}
Provides:       python-%{mname}-sip = %{version}-%{release}
Obsoletes:      python-%{mname}-sip < %{version}-%{release}
Provides:       python-%{mname}-api = %{version}-%{release}
Obsoletes:      python-%{mname}-api < %{version}-%{release}
Requires:       python-qt5-devel
Requires:       %{oldpython}(abi) = %{python_version}
Supplements:    (eric and python-%{mname})
Supplements:    (python-qt5-devel and python-%{mname})

%description devel
This package provides the framework API files for the Eric IDE.
and  the SIP files used to generate the Python bindings for %{name}

%prep
%autosetup -p1 -n PyQtWebEngine-%{version}

%build
%pyqt_build

%install
%pyqt_install

%files %{python_files}
%license LICENSE
%doc NEWS README
%dir %{python_sitearch}/PyQt5/
%{python_sitearch}/PyQt5/QtWebEngine.*
%{python_sitearch}/PyQt5/QtWebEngineCore.*
%{python_sitearch}/PyQt5/QtWebEngineWidgets.*
%{python_sitearch}/[Pp]y[Qq]t[Ww]eb[Ee]ngine-%{version}.dist-info/

%files %{python_files devel}
%license LICENSE
%dir %{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/
%{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/PyQtWebEngine.api
%{pyqt5_sipdir}/QtWebEngine/
%{pyqt5_sipdir}/QtWebEngineCore/
%{pyqt5_sipdir}/QtWebEngineWidgets/

%changelog
* Mon Jun  9 2025 Ben Greiner <code@bnavigator.de>
- Allow lowercase distinfo due to new pyqt-builder following PEP 639
* Fri Nov  8 2024 Ben Greiner <code@bnavigator.de>
- Fix requires_eq replacement gh#openSUSE/python-rpm-macros#185
* Tue Nov  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Avoid using requires_eq, which after the last modifications
  conflicts with python singlespec (order of expansion).
* Wed Sep 11 2024 Gustavo Pichorim Boiko <gboiko@suse.com>
- Disable building on all s390 and ppc platforms as Qt5WebEngine
  itself is not built on those archs.
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Enable SLE15 python module
- Clean old python2 directives
* Tue Jun 21 2022 Ben Greiner <code@bnavigator.de>
- Update to version 5.15.6
  * A bug-fix release.
* Tue Oct 19 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.15.5
  * PyQtWebEngine.msp: Only enable QWebEngineClientCertificateStore
    when SSL is enabled.
  * PyQtWebEngine.msp: Removed the internal QtWebEngineCore
    namespace.
- Merge sip and api subpackage into devel, update requirements
* Mon Sep 13 2021 Ben Greiner <code@bnavigator.de>
- Remove the Supplements for python-sip -- boo#1190441
* Fri Jun 18 2021 Ben Greiner <code@bnavigator.de>
- Provide the PyPI name
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.15.4
  * Packaging bug fixes.
- Fixes problems with packages checking the package metadata like
  boo#1183144
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- Update to 5.15.3
  * Sync release with PyQt5
- Switch all distros to SIP v5+
- Disable Python 2 build
* Tue Nov 24 2020 Benjamin Greiner <code@bnavigator.de>
- Update to Version 5.15.2
  * Build system changes
* Tue Sep 15 2020 Benjamin Greiner <code@bnavigator.de>
- Use sip5 where available
* Mon Sep 14 2020 Benjamin Greiner <code@bnavigator.de>
- Update to Version 5.15.1
  * A bug-fix release.
- drop update-timeline-patch again. Nobody uses nonexistent tags.
* Tue Sep  1 2020 Benjamin Greiner <code@bnavigator.de>
- Fix single line patch info for update-timeline.patch
- remove the skip python2 tumbleweed hack. Tumbleweed/Factory repos
  take care of it by themselves
- Update might fix boo#1176023
* Sat Aug 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update update-timeline.patch
* Thu Aug 27 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 5.15.0
  * Added support for Qt v5.15.0.
- v5.14.0 added support for Qt v5.14.0 in December 2019
- The source location has changed to PyPI
* Fri Mar 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Stop building the python2 package for openSUSE Tumbleweed.
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update update-timeline.patch for Qt 5.14.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.13.2
  * Added PYQT_WEBENGINE_VERSION and PYQT_WEBENGINE_VERSION_STR.
  * Added support for SIP v5.
* Fri Sep 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.1
  * Added the missing QWebEnginePage.Feature.Notifications enum member.
  * Fix building against Qt v5.12 and earlier.
  * Fixed building when Qt doesn't support QtWebChannel.
  * Added support for sip v5.
- Add update-timeline.patch
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.0
  * Bindings updated for QtWebEngine 5.13.0
* Wed Apr 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.12.1
  * Fixed the configure.py options that relate to stub files.
- Run spec-cleaner
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version (5.12)
